#include <stdio.h>
#include <stdlib.h>
#include <unistd.h>
#include <sys/types.h>
#include <sys/stat.h>
#include <fcntl.h>
#include <termios.h>
#include <errno.h>
#include <string.h>

int main(int argc, char * argv[])
{
	int fd;
	struct termios options;
	int i;

	if (argc < 4) {
		fprintf(stderr, "Usage: %s ttydev string1 string2\n", argv[0]);
		return 1;
	}

	fd = open(argv[1], O_RDWR | O_NOCTTY);
	if (fd < 0) {
		perror("Failed to open tty device");
		return 1;
	}
	
	tcgetattr(fd, &options);
	tcflush(fd, TCIOFLUSH);
	cfsetispeed(&options, B9600);
	cfsetospeed(&options, B9600);
	options.c_cflag &= ~CSIZE; options.c_cflag |= CS8;		/* 8 data bits */
	options.c_cflag &= ~PARENB;	options.c_iflag &= ~INPCK;	/* no parity */
	options.c_cflag &= ~CSTOPB;								/* 1 stop bit */
	options.c_cflag &= ~CRTSCTS;
	options.c_cc[VTIME] = 30;
	options.c_cc[VMIN] = 0;
	options.c_lflag  &= ~(ICANON | ECHO | ECHOE | ISIG);
	options.c_oflag  &= ~OPOST;
	
	if (tcsetattr(fd, TCSANOW, &options) != 0) {
		perror("Failed to set serial options");
		close(fd);
		return 1;
	}

	unsigned char buffer[17];

	/* Sync with LCD device */
	memset(buffer, 0, 17);
	write(fd, buffer, 17);

	buffer[0] = 0x32; write(fd, buffer, 1);
	for (i = 0; i < 2; i++) {
		unsigned int l;

		memset(buffer, ' ', 17);
		buffer[0] = 0x10 | i;
		l = strlen(argv[2 + i]);
		if (l > 16) l = 16;
		memcpy(buffer + 1, argv[2 + i], l);

		write(fd, buffer, 17);
	}
	buffer[0] = 0x33; write(fd, buffer, 1);

	tcdrain(fd);
	sleep(1);
	close(fd);

	return 0;
}
